#!/bin/bash
set -ex -o pipefail

# On latest Mac OS X 10.7.4 with latest Xcode 4.3.2 (incl. Command Line Tools):

mkdir /Volumes/hfs+/git/lo

# checkout and setup macports for use when building libreoffice
svn checkout http://svn.macports.org/repository/macports/trunk \
 /Volumes/hfs+/git/lo/mports-src
 # "https" instead of "http" fails to work non-interactively due to:
 #   Error validating server certificate for 'https://svn.macports.org:443':
 #    - The certificate is not issued by a trusted authority. Use the
 #      fingerprint to validate the certificate manually!
 #   Certificate information:
 #    - Hostname: *.macports.org
 #    - Valid: from Tue, 22 Feb 2011 17:29:43 GMT until Tue, 18 Mar 2014
 #      23:36:56 GMT
 #    - Issuer: 07969287, http://certificates.godaddy.com/repository,
 #      GoDaddy.com, Inc., Scottsdale, Arizona, US
 #    - Fingerprint:
 #      4d:ea:4a:77:55:ac:8e:2e:9e:11:8a:59:3d:ec:c7:45:7d:b0:72:19
 #   (R)eject, accept (t)emporarily or accept (p)ermanently?
(cd /Volumes/hfs+/git/lo/mports-src/base && ./configure \
 --prefix=/Volumes/hfs+/git/lo/mports --with-no-root-privileges \
 --with-applications-dir=/Volumes/hfs+/git/lo/mports-apps \
 --with-tclpackage=/Volumes/hfs+/git/lo/mports-tcl && make && make install) \
 || exit 1

# Update and install packages in macports
/Volumes/hfs+/git/lo/mports/bin/port selfupdate
/Volumes/hfs+/git/lo/mports/bin/port install libidl +universal
/Volumes/hfs+/git/lo/mports/bin/port install automake doxygen grep pkgconfig

# Create symbolic links to your newly installed macport programs
mkdir /Volumes/hfs+/git/lo/bin
ln -s /Volumes/hfs+/git/lo/mports/bin/aclocal /Volumes/hfs+/git/lo/bin/
ln -s /Volumes/hfs+/git/lo/mports/bin/autoconf /Volumes/hfs+/git/lo/bin/
ln -s /Volumes/hfs+/git/lo/mports/bin/autom4te /Volumes/hfs+/git/lo/bin/
ln -s /Volumes/hfs+/git/lo/mports/bin/doxygen /Volumes/hfs+/git/lo/bin/

mkdir /Volumes/hfs+/git/lo/pkgconfig
ln -s /Volumes/hfs+/git/lo/mports/lib/pkgconfig/glib-2.0.pc \
 /Volumes/hfs+/git/lo/pkgconfig/
ln -s /Volumes/hfs+/git/lo/mports/lib/pkgconfig/libIDL-2.0.pc \
 /Volumes/hfs+/git/lo/pkgconfig/

# clone libreoffice source code (I don't have ssh access so I need to use these lines)
git clone git://anongit.freedesktop.org/libreoffice/core \
 /Volumes/hfs+/git/lo/core

# clone libreoffice source code (If you have ssh access use these lines)
git clone ssh://git.freedesktop.org/git/libreoffice/core \
 /Volumes/hfs+/git/lo/core

# moz/unxmacxi/misc/build/mozilla/configure:20225 fails with "egrep: Regular
# expression too big" with default /usr/bin/egrep ("egrep (GNU grep) 2.5.1"),
# and adding this replacement to /Volumes/hfs+/git/lo/bin (which is added to
# PATH) does not help, as config_host.mk contains a rewritten PATH (where
# /Volumes/hfs+/git/lo/bin would always go after /usr/bin):
ln -s /Volumes/hfs+/git/lo/mports/bin/egrep \
 /Volumes/hfs+/git/lo/core/solenv/bin/

# moz/unxmacxi/misc/build/mozilla/gfx/src/mac/nsRegionPool.cpp uses NewRgn,
# DisposeRgn, etc. that got removed in 10.7 SDK:
cat >/Volumes/hfs+/git/lo/core/autogen.lastrun <<\EOF
--disable-ccache
--disable-linkoo
--disable-zenity
--enable-binfilter
--enable-dbgutil
--enable-epm
--enable-mozilla
--enable-python=internal
--enable-werror
--with-lang=en-US
--with-macosx-version-min-required=10.6
--with-max-jobs=2
--with-num-cpus=2
CC=clang -m32
CXX=clang++ -m32
EOF

ulimit -c unlimited

cd /Volumes/hfs+/git/lo/core
printf '%s' /Volumes/hfs+/git | grep -Fqv : || exit 1
PATH=${PATH:?}:/Volumes/hfs+/git/lo/bin \
 PKG_CONFIG=/Volumes/hfs+/git/lo/mports/bin/pkg-config \
 PKG_CONFIG_LIBDIR=/Volumes/hfs+/git/lo/pkgconfig make check